# Numfys fysikkbibliotek

## Aktivering

```
.env/Scripts/Activate.ps1
code .
```

## Kompilering og kjøring

```
maturin develop
py .\_python\preex.py
```

## Originalt oppsett

```
py -m venv .env
pip install -f requirements.txt
```